# stylelens-admin


## Setup environmant variables for DB connection
```bash
export DB_ADMIN_HOST={your_db_host_url}
export DB_ADMIN_PORT={your_db_port_url}
export DB_ADMIN_NAME={your_db_name}
export DB_ADMIN_USER={your_db_user}
export DB_ADMIN_PASSWORD={your_db_password}
```
